@@ -1,18 +1,40 @@
 test_that("success request returns response", {
-  resp <- request_test() %>% req_perform()
+  req <- request_test()
+  resp <- req_perform(req)
   expect_s3_class(resp, "httr2_response")
+  expect_equal(resp$request, req)
 })
 
-test_that("curl and http errors become errors", {
-  req <- request_test("/delay/:secs", secs = 1) %>% req_timeout(0.1)
-  expect_error(req_perform(req), class = "httr2_failed")
+test_that("curl errors become errors", {
+  local_mocked_bindings(
+    req_perform1 = function(...) abort("Failed to connect")
+  )
 
+  req <- request("http://127.0.0.1")
+  expect_snapshot(req_perform(req), error = TRUE)
+  expect_error(req_perform(req), class = "httr2_failure")
+
+  # and captures request
+  cnd <- catch_cnd(req_perform(req), classes = "error")
+  expect_equal(cnd$request, req)
+})
+
+test_that("http errors become errors", {
   req <- request_test("/status/:status", status = 404)
   expect_error(req_perform(req), class = "httr2_http_404")
+  expect_snapshot(req_perform(req), error = TRUE)
+
+  # and captures request
+  cnd <- catch_cnd(req_perform(req), classes = "error")
+  expect_equal(cnd$request, req)
 
   # including transient errors
   req <- request_test("/status/:status", status = 429)
-  expect_error(req_perform(req), class = "httr2_http_429")
+  expect_snapshot(req_perform(req), error = TRUE)
+
+  req_perform(req) %>%
+    expect_error(class = "httr2_http_429") %>%
+    expect_no_condition(class = "httr2_sleep")
 })
 
 test_that("can force successful HTTP statuses to error", {
@@ -65,11 +87,16 @@ test_that("can last response is NULL if it fails", {
   expect_equal(last_response(), NULL)
 })
 
-test_that("checks verbosity value", {
+test_that("checks input types", {
   req <- request_test()
-  expect_snapshot(req_perform(req, verbosity = 1.5), error = TRUE)
+  expect_snapshot(error = TRUE, {
+    req_perform(req, path = 1)
+    req_perform(req, verbosity = 1.5)
+    req_perform(req, mock = 7)
+  })
 })
 
+
 # dry run -----------------------------------------------------------------
 
 test_that("req_dry_run() returns useful data", {
